@@ -250,7 +250,7 @@ void MessageTest::testBidiSpoofing()
     //const QString PDF( QChar( 0x202C ) );
 
     const QByteArray senderAndRLO =
-        encodeRFC2047String(QLatin1String("Sender") + RLO + QLatin1String(" <sender@test.org>"), "utf-8");
+        encodeRFC2047String(QString(QLatin1String("Sender") + RLO + QLatin1String(" <sender@test.org>")), "utf-8");
 
     // The display name of the "From" has an RLO, make sure the KMime parser balances it
     QByteArray data =
@@ -557,7 +557,6 @@ void MessageTest::testEncapsulatedMessages()
 
 void MessageTest::testOutlookAttachmentNaming()
 {
-    KMime::setUseOutlookAttachmentEncoding(true);
     // Try and decode
     KMime::Message::Ptr msg = readAndParseMail(QStringLiteral("outlook-attachment.mbox"));
     QVERIFY(msg->attachments().count() == 1);
@@ -577,8 +576,7 @@ void MessageTest::testOutlookAttachmentNaming()
     attachment->contentDisposition()->setRFC2047Charset("ISO-8859-1"); // default changed to UTF-8 in KF6, which is fine, but breaks the test
     attachment->assemble();
     qDebug() << "got:" << attachment->contentDisposition()->as7BitString(false);
-    QCOMPARE(attachment->contentDisposition()->as7BitString(false), QByteArray("attachment; filename=\"=?ISO-8859-1?Q?=E5=2Ediff?=\""));
-    KMime::setUseOutlookAttachmentEncoding(false);
+    QCOMPARE(attachment->contentDisposition()->as7BitString(false), QByteArray("attachment; filename*=ISO-8859-1''%E5%2Ediff"));
 }
 
 void MessageTest::testEncryptedMails()
@@ -647,18 +645,6 @@ void MessageTest::testBug392239()
     QCOMPARE(msg->contents().size(), 0);
     QCOMPARE(msg->contentTransferEncoding()->encoding(), KMime::Headers::CEbase64);
     QCOMPARE(msg->decodedText().toUtf8().data(), "Following this paragraph there is a double line break which should result in vertical spacing.\r\rPreceding this paragraph there is a double line break which should result in vertical spacing.\r");
-    const QByteArray data = KMime::CRtoLF(msg->decodedText().toUtf8());
-    QCOMPARE(data, "Following this paragraph there is a double line break which should result in vertical spacing.\n\nPreceding this paragraph there is a double line break which should result in vertical spacing.\n");
-}
-
-void MessageTest::testCRtoLF()
-{
-    QByteArray data = "Subject: Test\n";
-    QCOMPARE(CRtoLF(data), "Subject: Test\n");
-    data = "Subject: Test\r";
-    QCOMPARE(CRtoLF(data), "Subject: Test\n");
-    data = "Subject: Test\r\n";
-    QCOMPARE(CRtoLF(data), "Subject: Test\r\n");
 }
 
 void MessageTest::testBugAttachment387423()
