@@ -367,11 +367,6 @@ public:
   */
   [[nodiscard]] int storageSize() const;
 
-  /**
-    Line count of this Content and all sub-Contents.
-  */
-  [[nodiscard]] int lineCount() const;
-
   /**
     Returns the Content body raw data.
 
