@@ -13,15 +13,16 @@
 #include "kmime_headers.h"
 #include "kmime_util.h"
 #include "kmime_util_p.h"
-#include "kmime_codecs.h"
+#include "kmime_codecs_p.h"
 #include "kmime_dateformatter.h"
 #include "kmime_debug.h"
-#include "kmime_warning.h"
+#include "kmime_warning_p.h"
 
 #include <KCodecs>
 
 #include <QMap>
 #include <QStringDecoder>
+#include <QTimeZone>
 
 #include <cassert>
 #include <cctype> // for isdigit
@@ -48,8 +49,7 @@ namespace HeaderParsing
 // parse the encoded-word (scursor points to after the initial '=')
 bool parseEncodedWord(const char *&scursor, const char *const send,
                       QString &result, QByteArray &language,
-                      QByteArray &usedCS, const QByteArray &defaultCS,
-                      bool forceCS)
+                      QByteArray &usedCS, const QByteArray &defaultCS)
 {
     // make sure the caller already did a bit of the work.
     assert(*(scursor - 1) == '=');
@@ -181,7 +181,7 @@ bool parseEncodedWord(const char *&scursor, const char *const send,
 
     // try if there's a (text)codec for the charset found:
     QStringDecoder textCodec;
-    if (forceCS || maybeCharset.isEmpty()) {
+    if (maybeCharset.isEmpty()) {
         textCodec = QStringDecoder(defaultCS.constData());
         if (!textCodec.isValid()) {
             textCodec = QStringDecoder(QStringDecoder::Latin1);
@@ -2044,8 +2044,7 @@ bool parseDateTime(const char *&scursor, const char *const send,
         maybeTime = QTime(0, 0, 0);
     }
 
-    result = QDateTime(maybeDate, maybeTime, Qt::OffsetFromUTC, secsEastOfGMT);
-    //result = QDateTime( maybeDateTime, QDateTime::Spec( QDateTime::OffsetFromUTC, secsEastOfGMT ) );
+    result = QDateTime(maybeDate, maybeTime, QTimeZone::fromSecondsAheadOfUtc(secsEastOfGMT));
     if (!result.isValid()) {
         return false;
     }
