@@ -47,15 +47,13 @@ namespace HeaderParsing
   @param usedCS    the used charset is returned here
   @param defaultCS the charset to use in case the detected
                    one isn't known to us.
-  @param forceCS   force the use of the default charset.
 
   @return true if the input string was successfully decode; false otherwise.
 */
 [[nodiscard]] KMIME_EXPORT bool
 parseEncodedWord(const char *&scursor, const char *const send, QString &result,
                  QByteArray &language, QByteArray &usedCS,
-                 const QByteArray &defaultCS = QByteArray(),
-                 bool forceCS = false);
+                 const QByteArray &defaultCS = QByteArray());
 
 //
 // The parsing squad:
