@@ -21,7 +21,7 @@
 #include "kmime_mdn.h"
 #include "kmime_version.h"
 #include "kmime_util.h"
-#include "kmime_codecs.h"
+#include "kmime_codecs_p.h"
 #include "kmime_debug.h"
 
 #include <KLocalizedString>
